@@ -18,25 +18,36 @@
 # You should have received a copy of the GNU General Public License along with along with
 # this program. If not, see <http://www.gnu.org/licenses/>.
 #
-
-
-def tendencySymbol(from_size, to_size):
-    if from_size > to_size:
-        return "*"
-    return ""
-
-
-def formatMemChange(what, from_size, to_size):
-    tendency_symbol = tendencySymbol(from_size, to_size)
-    difference = to_size - from_size
-    return "%s: %d -> %d bytes (%+d bytes) %s" % (
-        what,
-        from_size,
-        to_size,
-        difference,
-        tendency_symbol,
-    )
+import inspect
+import os
+from distutils import dir_util
 
 
 def listIntersection(l1, l2):
     return sorted(list(set(l1) & set(l2)))
+
+
+def getDirectoryThatStoresModule(obj):
+    file_that_stores_class = inspect.getfile(type(obj))
+    return os.path.dirname(file_that_stores_class)
+
+
+def deprecationWarning(feature):
+    print(
+        """\
+*******************************************************************************
+PLEASE NOTE: Feature '%s' is deprecated and will likely be removed
+             from future versions of the software.
+*******************************************************************************
+"""
+        % feature
+    )
+
+
+def getRelpath(html_output_file, target_dir):
+    html_dirname = os.path.dirname(html_output_file)
+    return os.path.relpath(target_dir, html_dirname)
+
+
+def recursiveCopy(source_dir, target_dir):
+    dir_util.copy_tree(source_dir, target_dir)
